.. _filters:

===================
Common filter names
===================

The filters for which convolved fluxes are available varies depending on the model package. However, The following list gives common filter names:

========== ======================
Short name       Filter
========== ======================
   BU        Bessel U-Band
   BB        Bessel B-Band
   BV        Bessel V-Band
   BR        Bessel R-Band
   BI        Bessel I-Band
   2J        2MASS J-Band
   2H        2MASS H-Band
   2K        2MASS K-Band
   UL        UKIRT L-Band
   LP        UKIRT L'-Band
   UM        UKIRT M-Band
   I1        IRAC Band [1]
   I2        IRAC Band [2]
   I3        IRAC Band [3]
   I4        IRAC Band [4]
   XA        MSX Band A
   XC        MSX Band C
   XD        MSX Band D
   XE        MSX Band E
   M1        MIPS 24
   M2        MIPS 70
   M3        MIPS 160
   S1        IRAS 12 microns
   S2        IRAS 25 microns
   S3        IRAS 60 microns
   S4        IRAS 100 microns
   W1        Scuba 450WB microns
   W2        Scuba 850WB microns
   N1        Scuba 350NB microns
   N2        Scuba 450NB microns
   N3        Scuba 750NB microns
   N4        Scuba 850NB microns
========== ======================
